#
# spec file for package lalmetaio
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define shlib lib%{name}11
# NEP 29: python36-numpy and co. in TW are no more
%define skip_python36 1
# Support for py2 dropped by uostream
%define skip_python2 1
# octave >= 6 not supported
%bcond_with    octave

Name:           lalmetaio
Version:        4.0.5
Release:        2.1
Summary:        LSC Algorithm MetaIO Library
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Physics
URL:            https://wiki.ligo.org/Computing/DASWG/LALSuite
Source:         https://software.igwn.org/sources/source/lalsuite/%{name}-%{version}.tar.xz
#Git-Clone:     https://git.ligo.org/lscsoft/lalsuite.git
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module lal >= 7.1.0}
BuildRequires:  %{python_module numpy >= 1.7}
BuildRequires:  %{python_module numpy-devel >= 1.7}
BuildRequires:  %{python_module py}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
%if 0%{?suse_version} < 1550
BuildRequires:  python-xml
%endif
BuildRequires:  swig
BuildRequires:  pkgconfig(lal) >= 7.1.0
BuildRequires:  pkgconfig(libmetaio)
%if %{with octave}
BuildRequires:  octave-lal >= 7.1.0
BuildRequires:  pkgconfig(octave)
%endif
# SECTION For tests
BuildRequires:  %{python_module pytest}
# /SECTION
Requires:       python-lal >= 7.1.0
Requires:       python-numpy >= 1.7
ExcludeArch:    %{ix86}

%python_subpackages

%description
The LSC Algorithm MetaIO Library for gravitational wave data analysis.

%package -n %{shlib}
Summary:        Shared library for libmetaio - LIGO Light-Weight XML library
Group:          Productivity/Scientific/Physics

%description -n %{shlib}
This package contains the shared-object libraries needed to run applications
that use the LAL MetaIO library.

%package -n %{name}-devel
Summary:        Development files for LAL metaio
Group:          Development/Libraries/C and C++
Requires:       %{shlib} = %{version}
Requires:       pkgconfig(lal)
Requires:       pkgconfig(libmetaio)

%description  -n %{name}-devel
This package contains sources and header files needed to build applications
that use the LAL MetaIO library.

%if %{with octave}
%package -n octave-lalmetaio
Summary:        Octave bindings for LAL MetaIO
Group:          Productivity/Scientific/Physics
Requires:       octave-lal
%requires_eq    octave-cli

%description -n octave-lalmetaio
This package provides the necessary files for using LAL MetaIO with octave.
%endif

%prep
%autosetup -p1

%build
%{python_expand # Necessary to run configure with multiple py3 flavours
export PYTHON=$python
mkdir ../${PYTHON}_build
cp -pr ./ ../${PYTHON}_build
pushd ../${PYTHON}_build
%configure \
  %{?with_octave:--enable-swig-octave} \
  %{!?with_octave:--disable-swig-octave}
make %{?_smp_mflags}
popd
}

%install
%{python_expand # py2 and py3 make_install
export PYTHON=$python
pushd ../${PYTHON}_build
%make_install
popd
}

# SECTION EXPORT LAL SPECIFIC ENV VARIABLES
# We do not use upstream's env files because they also set more generic
# variables (e.g. PATH) which may ruin setups

# NUKE UPSTREAM ENV SCRIPTS
rm %{buildroot}%{_sysconfdir}/%{name}-user-env.*

cat << EOF >> %{name}.sh
export LALMETAIO_PREFIX=%{_prefix}
export LALMETAIO_DATADIR=%{_datadir}/%{name}
EOF

cat << EOF >> %{name}.csh
setenv LALMETAIO_PREFIX "%{_prefix}"
setenv LALMETAIO_DATADIR "%{_datadir}/%{name}"
EOF

cat << EOF >> %{name}.fish
set LALMETAIO_PREFIX (echo "%{_prefix}" | %{_bindir}/sed -e 's| |:|g;')
set LALMETAIO_DATADIR (echo "%{_datadir}/%{name}" | %{_bindir}/sed -e 's| |:|g;')
EOF

install -D -m0644 %{name}.sh %{buildroot}%{_sysconfdir}/profile.d/%{name}.sh
install -D -m0644 %{name}.csh %{buildroot}%{_sysconfdir}/profile.d/%{name}.csh
install -D -m0644 %{name}.fish %{buildroot}%{_sysconfdir}/profile.d/%{name}.fish

# /SECTION

# SECTION REMOVE STATIC LIB AND LIBTOOL ARCHIVE
find %{buildroot}%{_libdir}/ -name "*.a" -delete -print
find %{buildroot} -type f -name "*.la" -delete -print
# /SECTION

%python_expand %fdupes %{buildroot}%{$python_sitearch}/%{name}/

%check
%{python_expand PYTHON=$python
pushd ../${PYTHON}_build
%make_build check
popd
}

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig

%files -n %{shlib}
%{_libdir}/*.so.*

%files -n %{name}-devel
%doc AUTHORS README.md
%license COPYING
%{_bindir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*
%config %{_sysconfdir}/profile.d/%{name}.*

%if %{with octave}
%files -n octave-%{name}
%dir %{_libdir}/octave/*/site
%dir %{_libdir}/octave/*/site/oct
%dir %{_libdir}/octave/*/site/oct/*
%{_libdir}/octave/*/site/oct/*/*.oct
%endif

%files %{python_files}
%{python_sitearch}/lalmetaio/

%changelog
* Sun Dec  1 2024 Atri Bhattacharya <badshah400@gmail.com>
- Fix use of %%requires_eq octave-cli
* Wed Sep 11 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.5:
  * No release notes.
* Sat Jul 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.4:
  * No release notes.
* Mon Jan 22 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.3:
  * No release notes.
* Tue May 23 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.1:
  * No release notes.
- Update shlib package name in keeping with upstream so version
  update to 11.
* Sun Feb 12 2023 Atri Bhattacharya <badshah400@gmail.com>
- Add python-py BuildRequires to fix tests that fail due to "No
  module named 'py._path'" errors.
* Fri Aug 19 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.0:
  * No release notes.
- Update so version to match upstream.
- Update source URL.
* Sun Jan  2 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.1.0:
  * No release notes.
- Drop python2 support in keeping with upstream.
* Fri Feb 26 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to 2.0.2:
  * No release notes.
* Fri Feb 12 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.0.1
  * no changelog
- Skip python36 build in TW, because python36-numpy and co. are
  no more.
- Drop reproducible.patch fixed upstream
* Thu Jan 21 2021 Atri Bhattacharya <badshah400@gmail.com>
- Fix dependency for tests and test runs for multi-versioned
  python.
* Mon Jan 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Disable octave bindings, since octave >= 6 isn't supported.
* Thu Nov 19 2020 Atri Bhattacharya <badshah400@gmail.com>
- Disable builds for 32-bit archs where lal is not supported.
* Fri Nov  6 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Build without octave bindings on Leap 15.x, requires SWIG 4.0
* Thu Oct 29 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Sat Aug 15 2020 Atri Bhattacharya <badshah400@gmail.com>
- Implement tests as part of %%check section; BuildRequires:
  python3-pytest needed for python tests.
* Tue Jul  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.1:
  * No release notes.
- Drop lalmetaio-build-octave44-with-swig3.patch: fixed upstream;
  also drop autoreconf command before configure and BuildRequires:
  libtool all required for this patch.
- Re-enable octave bindings: fixed upstream.
* Tue Jun 30 2020 Atri Bhattacharya <badshah400@gmail.com>
- Disable octave support as compilation error with current swig.
* Wed Apr 22 2020 Atri Bhattacharya <badshah400@gmail.com>
- BuildRequires: python-xml only for openSUSE <= 15.2 since
  python2 is disabled for newer openSUSE.
* Sun Feb  2 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.0:
  * O3b release.
- Rebase lalmetaio-build-octave44-with-swig3.patch for updated
  version.
* Mon Sep 30 2019 Atri Bhattacharya <badshah400@gmail.com>
- Build both python2 and python3 packages.
* Mon Jul 22 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.1:
  * O3 release
- Changes from version 1.5.0:
  * ER14 release.
- Rebase lalmetaio-build-octave44-with-swig3.patch to conform to
  upstream's reworking for swig and octave version tests.
* Fri Feb  8 2019 badshah400@gmail.com
- Switch builds to python2; add python-xml to BuildRequires.
* Thu Feb  7 2019 badshah400@gmail.com
- Add octave-cli to Requires for octave-%%{name}.
* Thu Feb  7 2019 badshah400@gmail.com
- Update Requires for -devel pkg and python modules.
* Sun Jan 27 2019 badshah400@gmail.com
- Add lalmetaio-build-octave44-with-swig3.patch: allow building
  octave bindings with swig 3.0.x rather than requiring swig 4.x.
* Sun Jan 27 2019 badshah400@gmail.com
- Initial package
